using System;
using System.Collections.Generic;
using System.Text;

namespace SVVClient_cs
{
    enum barva { bPrazna, bJaz, bNasprotnik }

    /* Podatkovni tip Polje -- igralno polje za igro "4 v vrsto"
     * 
     * uporaba:
     *  Polje p = new Polje(13,17);       -- naredi novo polje dimenzij 13x17
     *  Polje q = new Polje(p);           -- naredi novo polje, katerega dimenzije 
     *                                        in barve celic so identicne polju p
     *  int v = p.visina;                 -- prebere visino
     *  int s = p.sirina;                 -- prebere sirino
     * 
     *  p.izpisi();                       -- s Console.Write() izpise polje
     *  p.dodaj(2, barva.bNasprotnik);    -- najnizjo(!) prazno celico polja pobarva z
     *                                        nasprotnikovo barvo
     *  p[1,2] = barva.bJaz;            -- celico (1,2) pobarva z mojo barvo
     *  barva b = p[3,4];               -- prebere barvo celice (3,4)
     */

    class Polje
    {
        private barva[,] p;

        public Polje(int sirina, int visina)
        {
            p = new barva[sirina,visina];
            for (int i = 0; i < sirina; i++)
            {
                for (int j = 0; j < visina; j++)
                {
                    p[i,j] = barva.bPrazna;
                }
            }
        }

        public Polje(Polje r)
        {
            p = new barva[r.sirina,r.visina];
            for (int i = 0; i < r.sirina; i++)
                for (int j = 0; j < r.visina; j++)
                    p[i, j] = r.p[i, j];
        }

        public barva this[int x, int y]
        {
            get
            {
                return p[x, y];
            }

            set
            {
                p[x, y] = value;
            }
        }

        public int visina
        {
            get
            {
                return p.GetLength(1);
            }
        }

        public int sirina
        {
            get
            {
                return p.GetLength(0);
            }
        }

        public void dodaj(int stolpec, barva b)
        {
            if (stolpec == -1) return;
            for (int i = 0; i < visina; i++)
            {
                if (p[stolpec, i] == barva.bPrazna)
                {
                    p[stolpec, i] = b;
                    return;
                }
            }
            throw new Exception("Stolpec ze poln.");
        }

        public void izpisi()
        {
            for (int y = visina - 1; y >= 0; y--)
            {
                for (int x = 0; x < sirina; x++)
                {
                    switch (p[x, y])
                    {
                        case barva.bJaz: Console.Write("*"); break;
                        case barva.bNasprotnik: Console.Write("o"); break;
                        default: Console.Write(" "); break;
                    }
                }
                Console.WriteLine();
            }
        }
    }
}
